@@ -24,7 +24,7 @@ namespace glz
    {
       template <auto Opts, class T, class Tag, is_context Ctx, class It0, class It1>
          requires(check_no_header(Opts))
-      GLZ_ALWAYS_INLINE static void op(T&& value, Tag&& tag, Ctx&& ctx, It0&& it, It1&& end)
+      GLZ_ALWAYS_INLINE static void op(T&& value, Tag&& tag, Ctx&& ctx, It0&& it, It1 end)
       {
          if constexpr (const_value_v<T>) {
             if constexpr (check_error_on_const_read(Opts)) {
@@ -32,19 +32,19 @@ namespace glz
             }
             else {
                // do not read anything into the const value
-               skip_value<BEVE>::op<Opts>(std::forward<Ctx>(ctx), std::forward<It0>(it), std::forward<It1>(end));
+               skip_value<BEVE>::op<Opts>(std::forward<Ctx>(ctx), std::forward<It0>(it), end);
             }
          }
          else {
             using V = std::remove_cvref_t<T>;
             from<BEVE, V>::template op<Opts>(std::forward<T>(value), std::forward<Tag>(tag), std::forward<Ctx>(ctx),
-                                             std::forward<It0>(it), std::forward<It1>(end));
+                                             std::forward<It0>(it), end);
          }
       }
 
       template <auto Opts, class T, is_context Ctx, class It0, class It1>
          requires(not check_no_header(Opts))
-      GLZ_ALWAYS_INLINE static void op(T&& value, Ctx&& ctx, It0&& it, It1&& end)
+      GLZ_ALWAYS_INLINE static void op(T&& value, Ctx&& ctx, It0&& it, It1 end)
       {
          if constexpr (const_value_v<T>) {
             if constexpr (check_error_on_const_read(Opts)) {
@@ -52,13 +52,13 @@ namespace glz
             }
             else {
                // do not read anything into the const value
-               skip_value<BEVE>::op<Opts>(std::forward<Ctx>(ctx), std::forward<It0>(it), std::forward<It1>(end));
+               skip_value<BEVE>::op<Opts>(std::forward<Ctx>(ctx), std::forward<It0>(it), end);
             }
          }
          else {
             using V = std::remove_cvref_t<T>;
             from<BEVE, V>::template op<Opts>(std::forward<T>(value), std::forward<Ctx>(ctx), std::forward<It0>(it),
-                                             std::forward<It1>(end));
+                                             end);
          }
       }
    };
@@ -68,21 +68,20 @@ namespace glz
    struct from<BEVE, T>
    {
       template <auto Opts, class Value, is_context Ctx, class It0, class It1>
-      GLZ_ALWAYS_INLINE static void op(Value&& value, Ctx&& ctx, It0&& it, It1&& end)
+      GLZ_ALWAYS_INLINE static void op(Value&& value, Ctx&& ctx, It0&& it, It1 end)
       {
          using V = std::decay_t<decltype(get_member(std::declval<Value>(), meta_wrapper_v<T>))>;
          from<BEVE, V>::template op<Opts>(get_member(std::forward<Value>(value), meta_wrapper_v<T>),
-                                          std::forward<Ctx>(ctx), std::forward<It0>(it), std::forward<It1>(end));
+                                          std::forward<Ctx>(ctx), std::forward<It0>(it), end);
       }
 
       template <auto Opts, class Value, class Tag, is_context Ctx, class It0, class It1>
          requires(check_no_header(Opts))
-      GLZ_ALWAYS_INLINE static void op(Value&& value, Tag&& tag, Ctx&& ctx, It0&& it, It1&& end)
+      GLZ_ALWAYS_INLINE static void op(Value&& value, Tag&& tag, Ctx&& ctx, It0&& it, It1 end)
       {
          using V = std::decay_t<decltype(get_member(std::declval<Value>(), meta_wrapper_v<T>))>;
          from<BEVE, V>::template op<Opts>(get_member(std::forward<Value>(value), meta_wrapper_v<T>),
-                                          std::forward<Tag>(tag), std::forward<Ctx>(ctx), std::forward<It0>(it),
-                                          std::forward<It1>(end));
+                                          std::forward<Tag>(tag), std::forward<Ctx>(ctx), std::forward<It0>(it), end);
       }
    };
 
@@ -90,7 +89,7 @@ namespace glz
    struct from<BEVE, T>
    {
       template <auto Opts>
-      GLZ_ALWAYS_INLINE static void op(auto&&, is_context auto&& ctx, auto&& it, auto&& end) noexcept
+      GLZ_ALWAYS_INLINE static void op(auto&&, is_context auto&& ctx, auto&& it, auto end) noexcept
       {
          if (invalid_end(ctx, it, end)) {
             return;
@@ -117,7 +116,7 @@ namespace glz
    struct from<BEVE, T>
    {
       template <auto Opts>
-      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end) noexcept
+      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end) noexcept
       {
          if (invalid_end(ctx, it, end)) {
             return;
@@ -166,7 +165,7 @@ namespace glz
    struct from<BEVE, T>
    {
       template <auto Opts, is_context Ctx, class It0, class It1>
-      static void op(auto&& value, Ctx&& ctx, It0&& it, It1&& end)
+      static void op(auto&& value, Ctx&& ctx, It0&& it, It1 end)
       {
          constexpr auto N = reflect<T>::size;
 
@@ -196,7 +195,7 @@ namespace glz
       template <auto Opts>
          requires(check_no_header(Opts))
       GLZ_ALWAYS_INLINE static void op(auto&& value, const uint8_t tag, is_context auto&& ctx, auto&& it,
-                                       auto&& end) noexcept
+                                       auto end) noexcept
       {
          if (invalid_end(ctx, it, end)) {
             return;
@@ -219,7 +218,11 @@ namespace glz
                         ctx.error = error_code::unexpected_end;
                         return;
                      }
-                     std::memcpy(&i, it, sizeof(i));
+                     using I = std::decay_t<decltype(i)>;
+                     std::memcpy(&i, it, sizeof(I));
+                     if constexpr (std::endian::native == std::endian::big && sizeof(I) > 1) {
+                        byteswap_le(i);
+                     }
                      value = static_cast<V>(i);
                      it += sizeof(i);
                   };
@@ -302,17 +305,23 @@ namespace glz
          if constexpr (is_volatile) {
             V temp;
             std::memcpy(&temp, it, sizeof(V));
+            if constexpr (std::endian::native == std::endian::big && sizeof(V) > 1) {
+               byteswap_le(temp);
+            }
             value = temp;
          }
          else {
             std::memcpy(&value, it, sizeof(V));
+            if constexpr (std::endian::native == std::endian::big && sizeof(V) > 1) {
+               byteswap_le(value);
+            }
          }
          it += sizeof(V);
       }
 
       template <auto Opts>
          requires(not check_no_header(Opts))
-      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end) noexcept
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end) noexcept
       {
          if (invalid_end(ctx, it, end)) {
             return;
@@ -328,7 +337,7 @@ namespace glz
    struct from<BEVE, T>
    {
       template <auto Opts>
-      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end) noexcept
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end) noexcept
       {
          using V = std::underlying_type_t<std::decay_t<T>>;
 
@@ -338,7 +347,15 @@ namespace glz
                return;
             }
 
-            std::memcpy(&value, it, sizeof(V));
+            if constexpr (std::endian::native == std::endian::big && sizeof(V) > 1) {
+               V temp;
+               std::memcpy(&temp, it, sizeof(V));
+               byteswap_le(temp);
+               value = static_cast<std::decay_t<T>>(temp);
+            }
+            else {
+               std::memcpy(&value, it, sizeof(V));
+            }
             it += sizeof(V);
          }
          else {
@@ -360,7 +377,15 @@ namespace glz
                return;
             }
 
-            std::memcpy(&value, it, sizeof(V));
+            if constexpr (std::endian::native == std::endian::big && sizeof(V) > 1) {
+               V temp;
+               std::memcpy(&temp, it, sizeof(V));
+               byteswap_le(temp);
+               value = static_cast<std::decay_t<T>>(temp);
+            }
+            else {
+               std::memcpy(&value, it, sizeof(V));
+            }
             it += sizeof(V);
          }
       }
@@ -371,7 +396,7 @@ namespace glz
    struct from<BEVE, T>
    {
       template <auto Opts>
-      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end) noexcept
+      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end) noexcept
       {
          if constexpr (check_no_header(Opts)) {
             using V = std::decay_t<T>;
@@ -380,8 +405,21 @@ namespace glz
                return;
             }
 
-            std::memcpy(&value, it, sizeof(V));
-            it += sizeof(V);
+            if constexpr (std::endian::native == std::endian::big) {
+               using X = typename V::value_type;
+               X real_part, imag_part;
+               std::memcpy(&real_part, it, sizeof(X));
+               it += sizeof(X);
+               std::memcpy(&imag_part, it, sizeof(X));
+               it += sizeof(X);
+               byteswap_le(real_part);
+               byteswap_le(imag_part);
+               value = V{real_part, imag_part};
+            }
+            else {
+               std::memcpy(&value, it, sizeof(V));
+               it += sizeof(V);
+            }
          }
          else {
             constexpr uint8_t header = tag::extensions | 0b00011'000;
@@ -416,8 +454,20 @@ namespace glz
                return;
             }
 
-            std::memcpy(&value, it, 2 * sizeof(V));
-            it += 2 * sizeof(V);
+            if constexpr (std::endian::native == std::endian::big) {
+               V real_part, imag_part;
+               std::memcpy(&real_part, it, sizeof(V));
+               it += sizeof(V);
+               std::memcpy(&imag_part, it, sizeof(V));
+               it += sizeof(V);
+               byteswap_le(real_part);
+               byteswap_le(imag_part);
+               value = std::decay_t<T>{real_part, imag_part};
+            }
+            else {
+               std::memcpy(&value, it, 2 * sizeof(V));
+               it += 2 * sizeof(V);
+            }
          }
       }
    };
@@ -426,7 +476,7 @@ namespace glz
    struct from<BEVE, T>
    {
       template <auto Opts>
-      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end) noexcept
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end) noexcept
       {
          if (invalid_end(ctx, it, end)) {
             return;
@@ -455,7 +505,7 @@ namespace glz
    struct from<BEVE, T>
    {
       template <auto Opts>
-      GLZ_ALWAYS_INLINE static void op(auto&& /*value*/, is_context auto&& ctx, auto&& it, auto&& end) noexcept
+      GLZ_ALWAYS_INLINE static void op(auto&& /*value*/, is_context auto&& ctx, auto&& it, auto end) noexcept
       {
          skip_string_beve(ctx, it, end);
       }
@@ -465,7 +515,7 @@ namespace glz
    struct from<BEVE, basic_raw_json<T>>
    {
       template <auto Opts>
-      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          parse<BEVE>::op<Opts>(value.str, ctx, it, end);
       }
@@ -475,7 +525,7 @@ namespace glz
    struct from<BEVE, basic_text<T>>
    {
       template <auto Opts>
-      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          parse<BEVE>::op<Opts>(value.str, ctx, it, end);
       }
@@ -485,7 +535,7 @@ namespace glz
    struct from<BEVE, T>
    {
       template <auto Opts>
-      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end) noexcept
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end) noexcept
       {
          constexpr uint8_t header = tag::extensions | 0b00001'000;
          if (invalid_end(ctx, it, end)) {
@@ -518,7 +568,7 @@ namespace glz
 
       template <auto Opts>
          requires(check_no_header(Opts))
-      GLZ_ALWAYS_INLINE static void op(auto&& value, const uint8_t, is_context auto&& ctx, auto&& it, auto&& end)
+      GLZ_ALWAYS_INLINE static void op(auto&& value, const uint8_t, is_context auto&& ctx, auto&& it, auto end)
       {
          const auto n = int_from_compressed(ctx, it, end);
          if (bool(ctx.error)) [[unlikely]] {
@@ -535,7 +585,7 @@ namespace glz
 
       template <auto Opts>
          requires(not check_no_header(Opts))
-      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          constexpr uint8_t header = tag::string;
 
@@ -575,7 +625,7 @@ namespace glz
    struct from<BEVE, T> final
    {
       template <auto Opts>
-      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          using V = range_value_t<std::decay_t<T>>;
 
@@ -639,6 +689,9 @@ namespace glz
 
                V x;
                std::memcpy(&x, it, sizeof(V));
+               if constexpr (std::endian::native == std::endian::big) {
+                  byteswap_le(x);
+               }
                it += sizeof(V);
                value.emplace(x);
             }
@@ -712,7 +765,7 @@ namespace glz
    struct from<BEVE, T> final
    {
       template <auto Opts>
-      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          using V = range_value_t<std::decay_t<T>>;
 
@@ -840,19 +893,35 @@ namespace glz
                   std::is_volatile_v<std::remove_reference_t<std::remove_pointer_t<decltype(value.data())>>>;
 
                if constexpr (is_volatile) {
-                  V temp;
                   for (size_t i = 0; i < n; ++i) {
                      if ((it + sizeof(V)) > end) [[unlikely]] {
                         ctx.error = error_code::unexpected_end;
                         return;
                      }
 
+                     V temp;
                      std::memcpy(&temp, it, sizeof(V));
+                     if constexpr (std::endian::native == std::endian::big) {
+                        byteswap_le(temp);
+                     }
                      value[i] = temp;
                      it += sizeof(V);
                   }
                }
+               else if constexpr (std::endian::native == std::endian::big && sizeof(V) > 1) {
+                  // On big endian, read and swap each element
+                  if ((it + n * sizeof(V)) > end) [[unlikely]] {
+                     ctx.error = error_code::unexpected_end;
+                     return;
+                  }
+                  for (size_t i = 0; i < n; ++i) {
+                     std::memcpy(&value[i], it, sizeof(V));
+                     byteswap_le(value[i]);
+                     it += sizeof(V);
+                  }
+               }
                else {
+                  // Little endian or single-byte: bulk memcpy
                   if ((it + n * sizeof(V)) > end) [[unlikely]] {
                      ctx.error = error_code::unexpected_end;
                      return;
@@ -869,6 +938,9 @@ namespace glz
                   }
 
                   std::memcpy(&x, it, sizeof(V));
+                  if constexpr (std::endian::native == std::endian::big) {
+                     byteswap_le(x);
+                  }
                   it += sizeof(V);
                }
             }
@@ -965,12 +1037,34 @@ namespace glz
             }
 
             if constexpr (contiguous<T>) {
-               std::memcpy(value.data(), it, n * sizeof(V));
-               it += n * sizeof(V);
+               if constexpr (std::endian::native == std::endian::big && sizeof(X) > 1) {
+                  // On big endian, read and swap each complex element's components
+                  for (size_t i = 0; i < n; ++i) {
+                     std::memcpy(&value[i], it, sizeof(V));
+                     X real_part = value[i].real();
+                     X imag_part = value[i].imag();
+                     byteswap_le(real_part);
+                     byteswap_le(imag_part);
+                     value[i] = V(real_part, imag_part);
+                     it += sizeof(V);
+                  }
+               }
+               else {
+                  // Little endian or single-byte: bulk memcpy
+                  std::memcpy(value.data(), it, n * sizeof(V));
+                  it += n * sizeof(V);
+               }
             }
             else {
                for (auto&& x : value) {
                   std::memcpy(&x, it, sizeof(V));
+                  if constexpr (std::endian::native == std::endian::big && sizeof(X) > 1) {
+                     X real_part = x.real();
+                     X imag_part = x.imag();
+                     byteswap_le(real_part);
+                     byteswap_le(imag_part);
+                     x = V(real_part, imag_part);
+                  }
                   it += sizeof(V);
                }
             }
@@ -1008,7 +1102,7 @@ namespace glz
       // Instead of hashing or linear searching, we just clear the input and overwrite the entire contents
       template <auto Opts>
          requires(pair_t<range_value_t<T>> && check_concatenate(Opts) == true)
-      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          using Element = typename T::value_type;
          using Key = typename Element::first_type;
@@ -1062,7 +1156,7 @@ namespace glz
    struct from<BEVE, T> final
    {
       template <auto Opts>
-      GLZ_ALWAYS_INLINE static void op(T& value, is_context auto&& ctx, auto&& it, auto&& end)
+      GLZ_ALWAYS_INLINE static void op(T& value, is_context auto&& ctx, auto&& it, auto end)
       {
          using Key = typename T::first_type;
 
@@ -1098,7 +1192,7 @@ namespace glz
    struct from<BEVE, T> final
    {
       template <auto Opts>
-      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          using Key = typename T::key_type;
 
@@ -1143,7 +1237,7 @@ namespace glz
          constexpr uint8_t key_tag = beve_key_traits<Key>::key_tag;
 
          if constexpr (beve_key_traits<Key>::as_number) {
-            Key key;
+            Key key{}; // Value-initialize to silence false positive -Wmaybe-uninitialized
             for (size_t i = 0; i < n; ++i) {
                if constexpr (Opts.partial_read) {
                   parse<BEVE>::op<no_header_on<Opts>()>(key, key_tag, ctx, it, end);
@@ -1181,7 +1275,7 @@ namespace glz
    struct from<BEVE, T> final
    {
       template <auto Opts, class V, size_t N>
-      GLZ_ALWAYS_INLINE static void op(V (&value)[N], is_context auto&& ctx, auto&& it, auto&& end) noexcept
+      GLZ_ALWAYS_INLINE static void op(V (&value)[N], is_context auto&& ctx, auto&& it, auto end) noexcept
       {
          parse<BEVE>::op<Opts>(std::span{value, N}, ctx, it, end);
       }
@@ -1192,7 +1286,7 @@ namespace glz
    struct from<BEVE, T> final
    {
       template <auto Opts>
-      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          if (invalid_end(ctx, it, end)) {
             return;
@@ -1235,7 +1329,7 @@ namespace glz
    struct from<BEVE, T> final
    {
       template <auto Opts>
-      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      GLZ_ALWAYS_INLINE static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          if (invalid_end(ctx, it, end)) {
             return;
@@ -1270,7 +1364,7 @@ namespace glz
    struct from<BEVE, T>
    {
       template <auto Opts>
-      GLZ_ALWAYS_INLINE static void op(auto&&, is_context auto&& ctx, auto&& it, auto&& end) noexcept
+      GLZ_ALWAYS_INLINE static void op(auto&&, is_context auto&& ctx, auto&& it, auto end) noexcept
       {
          if constexpr (check_no_header(Opts)) {
             skip_compressed_int(ctx, it, end);
@@ -1299,7 +1393,7 @@ namespace glz
    {
       template <auto Opts>
          requires(Opts.structs_as_arrays == true)
-      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          if constexpr (reflectable<T>) {
             constexpr auto N = detail::count_members<T>;
@@ -1350,7 +1444,7 @@ namespace glz
 
       template <auto Opts>
          requires(Opts.structs_as_arrays == false)
-      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          constexpr uint8_t type = 0; // string key
          constexpr uint8_t header = tag::object | type;
@@ -1491,7 +1585,7 @@ namespace glz
    struct from<BEVE, T> final
    {
       template <auto Opts>
-      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          if (invalid_end(ctx, it, end)) {
             return;
@@ -1523,7 +1617,7 @@ namespace glz
    struct from<BEVE, T> final
    {
       template <auto Opts>
-      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto&& end)
+      static void op(auto&& value, is_context auto&& ctx, auto&& it, auto end)
       {
          if (invalid_end(ctx, it, end)) {
             return;
@@ -1652,4 +1746,130 @@ namespace glz
    {
       return read_file_beve<opt_true<Opts, &opts::structs_as_arrays>>(value, file_name, buffer);
    }
+
+   // ===== Delimited BEVE support for multiple objects in one buffer =====
+
+   // Skip a delimiter byte if present at the current position
+   // Returns true if a delimiter was skipped, false otherwise
+   GLZ_ALWAYS_INLINE bool skip_beve_delimiter(auto&& it, auto end) noexcept
+   {
+      if (it < end && uint8_t(*it) == tag::delimiter) {
+         ++it;
+         return true;
+      }
+      return false;
+   }
+
+   // Read multiple delimiter-separated BEVE values from a buffer into a container
+   template <auto Opts = opts{}, class Container, class Buffer>
+      requires readable_array_t<Container> && (emplace_backable<Container> || !resizable<Container>)
+   [[nodiscard]] error_ctx read_beve_delimited(Container& values, Buffer&& buffer)
+   {
+      static_assert(sizeof(decltype(*buffer.data())) == 1);
+
+      if (buffer.empty()) {
+         if constexpr (resizable<Container>) {
+            values.clear();
+         }
+         return {};
+      }
+
+      context ctx{};
+      auto it = reinterpret_cast<const char*>(buffer.data());
+      auto end = it + buffer.size();
+      auto start = it;
+
+      if constexpr (resizable<Container>) {
+         values.clear();
+      }
+
+      size_t index = 0;
+      const size_t container_size = values.size();
+
+      while (it < end) {
+         // Skip delimiter if present (except before first value)
+         if (index > 0) {
+            skip_beve_delimiter(it, end);
+         }
+
+         if (it >= end) {
+            break;
+         }
+
+         if constexpr (emplace_backable<Container>) {
+            auto& value = values.emplace_back();
+            parse<BEVE>::template op<set_beve<Opts>()>(value, ctx, it, end);
+         }
+         else {
+            if (index >= container_size) {
+               ctx.error = error_code::exceeded_static_array_size;
+               break;
+            }
+            parse<BEVE>::template op<set_beve<Opts>()>(values[index], ctx, it, end);
+         }
+
+         if (bool(ctx.error)) [[unlikely]] {
+            return {ctx.error, ctx.custom_error_message, size_t(it - start), ctx.includer_error};
+         }
+
+         ++index;
+      }
+
+      return {ctx.error, ctx.custom_error_message, size_t(it - start), ctx.includer_error};
+   }
+
+   // Read multiple delimiter-separated BEVE values, returning the container
+   template <class Container, auto Opts = opts{}, class Buffer>
+      requires readable_array_t<Container> && (emplace_backable<Container> || !resizable<Container>)
+   [[nodiscard]] expected<Container, error_ctx> read_beve_delimited(Buffer&& buffer)
+   {
+      Container values{};
+      const auto ec = read_beve_delimited<Opts>(values, std::forward<Buffer>(buffer));
+      if (bool(ec)) [[unlikely]] {
+         return unexpected(ec);
+      }
+      return values;
+   }
+
+   // Read a single BEVE value from a buffer at a given offset.
+   // If a delimiter byte (0x06) is present at the offset, it is automatically skipped.
+   // Returns the total bytes consumed from offset (including any skipped delimiter),
+   // so the next read offset is simply: offset + *result
+   //
+   // Example:
+   //   size_t offset = 0;
+   //   while (offset < buffer.size()) {
+   //      auto result = glz::read_beve_at(value, buffer, offset);
+   //      if (!result) break;
+   //      offset += *result;  // correctly advances past delimiter + value
+   //   }
+   template <auto Opts = opts{}, read_supported<BEVE> T, class Buffer>
+   [[nodiscard]] glz::expected<size_t, error_ctx> read_beve_at(T& value, Buffer&& buffer, size_t offset = 0)
+   {
+      static_assert(sizeof(decltype(*buffer.data())) == 1);
+
+      if (offset >= buffer.size()) {
+         return glz::unexpected(error_ctx{error_code::unexpected_end});
+      }
+
+      context ctx{};
+      auto it = reinterpret_cast<const char*>(buffer.data()) + offset;
+      auto end = reinterpret_cast<const char*>(buffer.data()) + buffer.size();
+      auto start = it;
+
+      // Skip leading delimiter if present (included in returned byte count)
+      skip_beve_delimiter(it, end);
+
+      if (it >= end) {
+         return glz::unexpected(error_ctx{error_code::unexpected_end});
+      }
+
+      parse<BEVE>::template op<set_beve<Opts>()>(value, ctx, it, end);
+
+      if (bool(ctx.error)) [[unlikely]] {
+         return glz::unexpected(error_ctx{ctx.error, ctx.custom_error_message, size_t(it - start), ctx.includer_error});
+      }
+
+      return size_t(it - start); // total bytes consumed from offset (delimiter + value)
+   }
 }
